#include "configyyrename.h"

#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	yyleng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 65
#define YY_END_OF_BUFFER 66
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[464] =
    {   0,
        1,    1,   53,   53,   57,   57,   61,   61,   66,   64,
        1,   51,   52,    2,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   65,   53,   54,   65,   55,   65,   60,   57,   58,
       59,   65,   61,   62,   63,   65,   64,    0,    1,    2,
        2,    2,    2,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   53,    0,   60,    0,   57,   61,    0,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,

       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   44,   64,   64,   64,
       64,   64,   64,   43,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   40,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
        4,   64,   12,   64,   64,   21,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       31,   64,   64,   64,   64,   64,   64,   64,   64,   64,

       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   24,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   35,   64,   64,   64,   64,
       42,   64,    3,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   56,   64,   64,   64,   64,   64,
       13,   64,   64,   20,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,

       64,   64,   64,   64,   10,   64,   27,   64,   11,   64,
        8,    9,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   25,   64,   64,   48,   64,   64,   64,
       28,   64,   32,   26,   41,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   15,   64,
       64,   30,   64,   64,   64,   64,   64,   64,   64,   64,
       64,    6,   64,    5,   64,   64,   64,   64,   64,   64,
       64,   22,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   37,   34,
       64,   64,   17,   64,   64,   64,   64,   46,   64,   64,

       64,   33,    7,   64,   64,   36,   64,   14,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   18,   19,   64,
       64,   47,   64,   64,   64,   64,   64,   64,   64,   16,
       64,   64,   64,   64,   23,   64,   64,   64,   50,   64,
       64,   64,   64,   64,   45,   64,   64,   38,   49,   64,
       39,   29,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    7,    1,    1,    1,    1,    1,
        1,    8,    1,    9,    1,    1,    1,   10,    1,    1,
        1,    1,    1,    1,   11,   12,   13,   14,   15,   16,
       17,   18,   19,    1,   20,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
        1,   36,    1,    1,    1,    1,   37,   38,   39,   40,

       41,   42,   43,   44,   45,    1,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
       60,   61,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    2,    3,    4,    4,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[473] =
    {   0,
        0,    0,   59,   62,   66,   70,   73,   76, 1300, 1263,
       80, 1301, 1301,   83,   63,   71,   89,   75,   78,  101,
       81,  112,  102,  120,  109,  128,  115,  127,  138,  136,
      135,  182, 1262, 1301, 1301, 1301,   86, 1261, 1294, 1301,
     1301,  186, 1259, 1301, 1301,  156, 1257,  190,   91,    0,
      194,    0,    0,  172,  161,  173,  146,  168,  186,  191,
      196,  197,  209,  178,  203,  199,  205,  206,  214,  234,
      222,  228,  227,  241,  245,  236,  237,  250,  240,  256,
      248, 1249,  219, 1231,  294, 1264, 1229,  285,  271,  276,
      274,  278,  293,  275,  297,  300,  283,  208,  306,  301,

      309,  314,  249,  302,  310,  316,  320,  323,  331,  319,
      318,  327,  326,  333,  329,  361, 1228,  345,  358,  364,
      365,  349,  350, 1226,  363,  376,  374,  373,  385,  382,
      386,  391,  383,  396,  388,  416, 1224,  409,  415,  413,
      420,  411,  417,  424,  421,  423,  429,  433,  422,  450,
      445,  447,  456,  468,  475,  454,  470,  459,  476,  471,
      482,  484,  489,  486,  495,  496,  500,  501,  515,  503,
     1221,  504, 1220,  524,  512, 1219,  530,  518,  492,  525,
      527,  529,  532,  538,  556,  548,  561,  546,  558,  562,
     1218,  568,  571,  560,  589,  565,  581,  583,  587,  603,

      591,  607,  597,  593,  609,  596,  623,  613,  645,  624,
      626,  636,  628,  632,  651,  640,  635,  638,  644,  648,
      663,  670,  668,  671,  667,  661,  673,  674,  682,  665,
      681, 1216,  687,  689,  700,  694,  693,  712,  718,  698,
      701,  715,  719,  730,  716, 1091,  727,  735,  739,  742,
     1047,  737, 1033,  738,  744,  729,  745,  762,  755,  752,
      770,  764,  772,  781,  784,  780,  787,  786,  783,  791,
      790,  804,  796,  819,  977,  803,  824,  826,  809,  813,
      936,  828,  835,  918,  811,  815,  822,  839,  825,  832,
      829,  846,  847,  866,  852,  860,  861,  876,  858,  879,

      880,  881,  868,  882,  909,  878,  823,  886,  761,  870,
      760,  758,  892,  893,  894,  889,  904,  916,  903,  907,
      926,  902,  911,  754,  927,  935,  736,  919,  917,  939,
      726,  929,  653,  642,  555,  949,  944,  932,  942,  959,
      945,  951,  955,  961,  962,  966,  965,  984,  550,  987,
      967,  535,  980,  991,  988,  998,  982, 1003, 1005, 1009,
      995,  522, 1013,  460, 1002, 1021, 1008, 1017, 1018, 1038,
     1023,  457, 1034, 1040, 1031, 1041, 1043, 1049, 1050, 1057,
     1059, 1060, 1063, 1070, 1067, 1069, 1071, 1073,  444,  414,
     1080, 1062,  407, 1077, 1096, 1079, 1097,  403, 1083, 1089,

     1103,  390,  357, 1106, 1107,  335, 1104,  288, 1118, 1115,
     1110, 1099, 1125, 1126, 1132, 1137, 1119, 1146, 1144, 1130,
     1153, 1129, 1139, 1157, 1152, 1161, 1165,  284,  267, 1170,
     1173,  221, 1163, 1175, 1180, 1176, 1182, 1183, 1192,  177,
     1187, 1186, 1193, 1190,  171, 1202, 1209, 1210,  140, 1217,
     1203, 1212, 1225, 1227,  132, 1213, 1233,  110,   99, 1234,
       97,   85, 1301, 1270, 1274, 1278,  112, 1282, 1286,   82,
     1288, 1290
    } ;

static yyconst flex_int16_t yy_def[473] =
    {   0,
      463,    1,  464,  464,  465,  465,  466,  466,  463,  467,
      463,  463,  463,  468,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  469,  463,  463,  463,  469,  470,  463,  463,
      463,  470,  471,  463,  463,  471,  467,  467,  463,  472,
      468,  472,  468,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  469,  469,  470,  470,  463,  471,  471,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,

      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,

      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,

      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,

      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,    0,  463,  463,  463,  463,  463,  463,  463,
      463,  463
    } ;

static yyconst flex_int16_t yy_nxt[1363] =
    {   0,
       10,   11,   12,   12,   13,   14,   10,   10,   10,   10,
       15,   10,   16,   17,   10,   10,   10,   18,   19,   20,
       21,   10,   22,   23,   24,   10,   25,   26,   27,   28,
       29,   10,   30,   10,   31,   32,   15,   10,   16,   17,
       10,   10,   10,   18,   19,   20,   21,   10,   22,   23,
       24,   10,   25,   26,   27,   28,   29,   10,   30,   10,
       31,   34,   35,   36,   34,   35,   36,   39,   40,   40,
       41,   39,   40,   40,   41,   44,   44,   45,   44,   44,
       45,   49,   84,   54,   52,   50,   52,   52,   56,   82,
       82,   61,   49,   60,   37,   55,   50,   37,   48,   57,

       62,   42,   63,   58,   65,   42,   48,   59,   46,   54,
       48,   46,   47,   48,   56,   64,   48,   61,   53,   60,
       48,   55,   66,   73,   48,   57,   62,   76,   63,   58,
       65,   69,   48,   59,   48,   67,   48,   48,   70,   68,
       77,   64,   74,   71,   48,   48,   72,   48,   66,   73,
       48,   80,   79,   76,   78,   48,   75,   69,   81,   87,
       87,   67,   48,   48,   70,   68,   77,   48,   74,   71,
       48,   48,   72,   48,   93,   48,   91,   80,   79,   94,
       78,   48,   75,   47,   81,   47,   47,   84,   89,   84,
       84,   47,   90,   47,   47,   52,   48,   52,   52,   92,

       93,   95,   91,   48,   96,   94,   48,   48,   48,   98,
       97,  103,   48,   48,   89,   99,  100,  101,   90,  104,
      105,   48,   82,   82,  107,   92,   48,   95,  131,   53,
       96,   48,   48,  106,   48,   98,   97,  103,   48,  102,
       48,   48,  108,   48,   48,  104,  105,  109,  110,   48,
      107,  111,  112,  113,  131,  115,   48,   48,  137,  106,
      116,  117,   48,   48,  118,  102,  119,  114,  108,   48,
      121,   48,   48,  109,  110,   48,   48,  111,  112,  113,
       48,  115,  120,   48,   48,   48,  116,  117,   87,   87,
      118,   48,  119,  114,  122,   84,  121,   84,   84,  123,

      124,  125,   48,  126,  127,  130,   48,  133,  120,   48,
       48,   48,  128,   48,  129,  134,  132,  138,   48,   48,
      122,  135,  136,   48,  139,  123,  124,  125,   48,  126,
      127,  130,   48,  141,  140,   48,   48,   48,  128,  142,
      129,   48,  132,  138,   48,   48,  143,  144,  145,   48,
      139,   48,  147,   48,   48,   48,  146,  149,   48,  141,
      140,   48,   48,  148,   48,  142,   48,  150,   48,  152,
       48,  151,  143,  144,  145,  156,  153,  154,  147,  155,
       48,  157,  146,  149,   48,   48,  158,  159,  161,  148,
      160,  162,   48,   48,  168,  152,   48,  151,   48,   48,

       48,  156,  153,  154,  165,  155,  166,  157,   48,   48,
      163,   48,  158,  159,  161,  164,  160,   48,   48,  167,
       48,   48,  169,   48,  171,   48,   48,  170,  172,  173,
      165,   48,  166,  176,  174,  175,  163,  178,   48,  177,
      181,  164,   48,  179,   48,  167,   48,  180,   48,   48,
       48,   48,   48,  170,  172,   48,   48,   48,   48,   48,
      174,  175,  182,  178,   48,  177,  181,  185,   48,  179,
      186,  187,  194,  180,  188,  183,  195,  198,  184,   48,
       48,  190,   48,  189,  191,   48,  197,  196,  182,   48,
      192,   48,   48,  185,   48,   48,  186,  187,  194,  202,

      199,  183,  193,   48,  184,   48,   48,  201,  203,  189,
       48,   48,  197,  196,  200,  206,  192,   48,  204,   48,
      214,   48,  205,  208,   48,  202,  199,   48,  193,  207,
       48,   48,  211,  201,  203,   48,   48,  209,   48,   48,
      200,  206,  210,  212,  204,  213,  214,   48,  205,  208,
       48,  215,  217,   48,  216,  207,  219,   48,  211,   48,
       48,  218,   48,  209,   48,   48,  220,   48,  210,  212,
       48,  213,  224,   48,  232,  221,  225,  215,  217,  222,
      216,   48,  219,   48,  228,   48,  227,  218,  229,  226,
       48,   48,  220,   48,  223,   48,   48,   48,  224,  230,

       48,  221,  225,   48,  234,  222,   48,  235,  233,  242,
      228,  231,  227,  240,  229,  226,   48,  236,   48,  237,
      223,  238,   48,  239,   48,  230,   48,  244,   48,  241,
      234,   48,   48,  235,  233,  242,  243,  231,   48,  240,
      248,  251,   48,  236,   48,  237,  247,  238,   48,  239,
      249,  245,  256,  244,  246,  241,  250,  252,   48,   48,
      253,   48,  243,   48,  255,  257,  248,   48,  254,  258,
       48,   48,  247,   48,  261,   48,  249,   48,  256,   48,
       48,  259,  250,   48,  260,  262,   48,  263,   48,  264,
      255,  257,  266,  265,  254,  258,   48,  268,   48,  267,

       48,  270,   48,   48,  269,   48,   48,  259,   48,   48,
      260,  262,  271,  263,  272,  264,   48,   48,  266,  265,
      273,  275,   48,  268,   48,  267,  274,  270,   48,   48,
      269,  277,  276,   48,  278,   48,   48,  279,  271,  281,
      272,  280,  282,  283,  284,  285,  273,   48,  286,  287,
       48,   48,  274,   48,   48,  290,  288,  277,  276,  291,
      278,   48,   48,  279,   48,   48,  289,  280,  282,  283,
       48,   48,   48,   48,   48,  287,  292,   48,  294,   48,
       48,  290,  288,  293,  297,  291,  298,   48,  295,   48,
       48,  299,  289,   48,  296,   48,   48,   48,  300,   48,

      305,  303,  292,  306,  294,   48,  301,   48,  302,  293,
      297,  304,  298,  307,  295,   48,   48,  299,   48,   48,
      296,   48,   48,  308,  300,   48,   48,  303,  309,  306,
      310,   48,  301,  311,  302,  312,  313,  304,   48,   48,
      314,  316,  315,  317,   48,  319,   48,  318,   48,  308,
       48,  320,  323,  321,   48,  324,  310,   48,   48,   48,
       48,   48,  313,   48,   48,  322,  314,   48,  315,  317,
       48,  319,  326,  318,   48,  327,  328,  320,  323,  321,
      325,   48,   48,  329,  330,  331,  332,   48,  333,  334,
      335,  322,  338,   48,  336,   48,   48,  340,  341,  342,

      337,   48,  328,   48,  339,   48,  325,  344,  350,  329,
      330,   48,  332,   48,   48,   48,   48,   48,  338,  345,
      336,   48,  343,  340,   48,  356,  337,   48,   48,   48,
      339,  346,  347,  344,  348,  349,  352,   48,   48,   48,
      351,  362,   48,  357,   48,  345,   48,  353,  343,  358,
      354,   48,   48,   48,   48,  360,  359,  346,  347,  361,
      348,   48,   48,  355,   48,  363,  351,   48,  364,  357,
       48,   48,  365,  353,   48,  358,  354,   48,  366,   48,
       48,  367,  359,  368,   48,  361,   48,  371,  369,  355,
       48,  363,  370,  372,   48,  374,   48,   48,  365,  373,

       48,   48,   48,  375,  366,  376,  377,  367,  378,  368,
      379,  381,   48,  371,  369,   48,  380,   48,  370,   48,
      385,  374,   48,   48,  382,  373,   48,  389,  383,  375,
       48,  376,  377,   48,  378,  384,  379,   48,   48,  386,
       48,  387,  380,   48,   48,  388,  385,  390,   48,  393,
      382,  391,   48,   48,  383,  395,   48,  392,   48,  398,
      394,  384,  397,  399,  396,  386,   48,  387,   48,   48,
      401,  388,  402,   48,  400,   48,   48,  391,   48,  403,
      406,  395,   48,  392,   48,   48,  394,  407,  397,  408,
      396,  409,   48,  412,   48,   48,  401,   48,   48,  410,

      400,  404,   48,  405,   48,   48,   48,  415,   48,  411,
      413,  414,   48,  407,   48,   48,  422,  409,   48,  412,
      417,  418,  423,  416,   48,  410,   48,  404,  428,  405,
      419,   48,   48,  415,   48,  411,  413,  414,   48,   48,
      420,   48,   48,  421,  425,   48,  417,  418,  423,  416,
       48,  424,  426,   48,   48,  429,  419,  427,  431,  430,
       48,   48,  432,  433,   48,   48,  420,   48,  434,  421,
      425,  435,   48,  436,   48,  437,  438,  424,  426,   48,
      439,   48,  440,  427,  431,  430,  441,   48,   48,  433,
      444,  445,   48,  446,  434,  449,   48,  435,   48,  436,

       48,  437,  438,  442,  447,   48,  439,  443,   48,  448,
       48,   48,  441,  451,  452,   48,  444,   48,   48,  446,
      450,   48,   48,  453,  454,   48,  455,   48,   48,  442,
      447,  457,  456,  443,  458,  448,  459,   48,   48,  451,
      452,  460,  461,  462,   48,   48,  450,   48,   48,  453,
      454,   48,   48,   48,   48,   48,   48,  457,  456,   48,
       48,   48,   48,   48,   88,   86,   85,  460,   48,   48,
       33,   33,   33,   33,   38,   38,   38,   38,   43,   43,
       43,   43,   51,   51,   83,   51,   82,   82,   87,   87,
       52,   52,   48,   52,   88,   86,   85,   83,   48,  463,

        9,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463
    } ;

static yyconst flex_int16_t yy_chk[1363] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    3,    4,    4,    4,    5,    5,    5,
        5,    6,    6,    6,    6,    7,    7,    7,    8,    8,
        8,   11,  470,   15,   14,   11,   14,   14,   16,   37,
       37,   19,   49,   18,    3,   15,   49,    4,   15,   17,

       19,    5,   19,   17,   21,    6,   16,   17,    7,   15,
       18,    8,  467,   19,   16,   20,   21,   19,   14,   18,
      462,   15,   22,   25,   17,   17,   19,   27,   19,   17,
       21,   23,  461,   17,  459,   22,   20,   23,   24,   22,
       28,   20,   26,   24,   25,  458,   24,   22,   22,   25,
       27,   30,   29,   27,   28,   24,   26,   23,   31,   46,
       46,   22,   28,   26,   24,   22,   28,  455,   26,   24,
       31,   30,   24,   29,   57,  449,   55,   30,   29,   58,
       28,   57,   26,   32,   31,   32,   32,   42,   54,   42,
       42,   48,   54,   48,   48,   51,   55,   51,   51,   56,

       57,   59,   55,   58,   60,   58,  445,   54,   56,   62,
       61,   64,  440,   64,   54,   63,   63,   63,   54,   65,
       66,   59,   83,   83,   68,   56,   60,   59,   98,   51,
       60,   61,   62,   67,   66,   62,   61,   64,   65,   63,
       67,   68,   69,   98,   63,   65,   66,   70,   71,   69,
       68,   72,   73,   74,   98,   75,  432,   71,  103,   67,
       76,   77,   73,   72,   78,   63,   79,   74,   69,   70,
       81,   76,   77,   70,   71,   79,   74,   72,   73,   74,
       75,   75,   80,   81,  103,   78,   76,   77,   88,   88,
       78,   80,   79,   74,   89,   85,   81,   85,   85,   90,

       91,   92,  429,   93,   94,   97,   89,  100,   80,   91,
       94,   90,   95,   92,   96,  101,   99,  104,   97,  428,
       89,  102,  102,  408,  105,   90,   91,   92,   93,   93,
       94,   97,   95,  107,  106,   96,  100,  104,   95,  108,
       96,   99,   99,  104,  101,  105,  109,  110,  111,  102,
      105,  106,  113,  111,  110,  107,  112,  115,  108,  107,
      106,  113,  112,  114,  115,  108,  109,  116,  114,  119,
      406,  118,  109,  110,  111,  122,  119,  120,  113,  121,
      118,  123,  112,  115,  122,  123,  125,  126,  128,  114,
      127,  129,  403,  119,  135,  119,  116,  118,  125,  120,

      121,  122,  119,  120,  132,  121,  133,  123,  128,  127,
      130,  126,  125,  126,  128,  131,  127,  130,  133,  134,
      129,  131,  136,  135,  139,  402,  132,  138,  140,  141,
      132,  134,  133,  144,  142,  143,  130,  146,  398,  145,
      149,  131,  393,  147,  138,  134,  142,  148,  140,  390,
      139,  136,  143,  138,  140,  141,  145,  149,  146,  144,
      142,  143,  150,  146,  147,  145,  149,  151,  148,  147,
      152,  153,  156,  148,  154,  150,  157,  160,  150,  389,
      151,  155,  152,  154,  155,  150,  159,  158,  150,  156,
      155,  153,  372,  151,  158,  364,  152,  153,  156,  164,

      161,  150,  155,  154,  150,  157,  160,  163,  165,  154,
      155,  159,  159,  158,  162,  168,  155,  161,  166,  162,
      179,  164,  167,  170,  163,  164,  161,  179,  155,  169,
      165,  166,  175,  163,  165,  167,  168,  172,  170,  172,
      162,  168,  174,  177,  166,  178,  179,  175,  167,  170,
      169,  180,  182,  178,  181,  169,  184,  362,  175,  174,
      180,  183,  181,  172,  182,  177,  185,  183,  174,  177,
      352,  178,  188,  184,  196,  186,  189,  180,  182,  187,
      181,  188,  184,  186,  193,  349,  192,  183,  194,  190,
      335,  185,  185,  189,  187,  194,  187,  190,  188,  195,

      196,  186,  189,  192,  198,  187,  193,  199,  197,  206,
      193,  195,  192,  204,  194,  190,  197,  200,  198,  201,
      187,  202,  199,  203,  195,  195,  201,  208,  204,  205,
      198,  206,  203,  199,  197,  206,  207,  195,  200,  204,
      211,  214,  202,  200,  205,  201,  210,  202,  208,  203,
      212,  209,  218,  208,  209,  205,  213,  215,  207,  210,
      215,  211,  207,  213,  217,  219,  211,  214,  216,  220,
      217,  212,  210,  218,  223,  216,  212,  334,  218,  219,
      209,  221,  213,  220,  222,  224,  215,  225,  333,  226,
      217,  219,  228,  227,  216,  220,  226,  230,  221,  229,

      230,  233,  225,  223,  231,  222,  224,  221,  227,  228,
      222,  224,  234,  225,  235,  226,  231,  229,  228,  227,
      236,  238,  233,  230,  234,  229,  237,  233,  237,  236,
      231,  240,  239,  240,  241,  235,  241,  242,  234,  244,
      235,  243,  245,  247,  248,  249,  236,  238,  250,  252,
      242,  245,  237,  239,  243,  256,  254,  240,  239,  257,
      241,  331,  247,  242,  256,  244,  255,  243,  245,  247,
      248,  327,  252,  254,  249,  252,  258,  250,  260,  255,
      257,  256,  254,  259,  262,  257,  263,  260,  261,  324,
      259,  264,  255,  312,  261,  311,  309,  258,  265,  262,

      270,  268,  258,  271,  260,  261,  266,  263,  267,  259,
      262,  269,  263,  272,  261,  266,  264,  264,  269,  265,
      261,  268,  267,  273,  265,  271,  270,  268,  274,  271,
      276,  273,  266,  277,  267,  278,  279,  269,  276,  272,
      280,  283,  282,  285,  279,  287,  285,  286,  280,  273,
      286,  288,  291,  289,  274,  292,  276,  287,  307,  277,
      289,  278,  279,  282,  291,  290,  280,  290,  282,  285,
      283,  287,  294,  286,  288,  294,  295,  288,  291,  289,
      293,  292,  293,  296,  297,  298,  299,  295,  300,  301,
      302,  290,  306,  299,  303,  296,  297,  310,  313,  314,

      304,  294,  295,  303,  308,  310,  293,  316,  322,  296,
      297,  298,  299,  306,  300,  301,  302,  304,  306,  317,
      303,  308,  315,  310,  316,  328,  304,  313,  314,  315,
      308,  318,  319,  316,  320,  321,  325,  322,  319,  317,
      323,  338,  320,  329,  305,  317,  323,  326,  315,  330,
      326,  318,  329,  284,  328,  336,  332,  318,  319,  337,
      320,  321,  325,  326,  332,  339,  323,  338,  340,  329,
      326,  281,  341,  326,  330,  330,  326,  339,  342,  337,
      341,  343,  332,  344,  336,  337,  342,  347,  345,  326,
      343,  339,  346,  348,  340,  351,  344,  345,  341,  350,

      347,  346,  351,  353,  342,  354,  355,  343,  356,  344,
      357,  359,  275,  347,  345,  353,  358,  357,  346,  348,
      365,  351,  350,  355,  360,  350,  354,  369,  361,  353,
      361,  354,  355,  356,  356,  363,  357,  365,  358,  366,
      359,  367,  358,  367,  360,  368,  365,  370,  363,  374,
      360,  371,  368,  369,  361,  376,  366,  373,  371,  379,
      375,  363,  378,  380,  377,  366,  375,  367,  253,  373,
      382,  368,  383,  370,  381,  374,  376,  371,  377,  384,
      387,  376,  251,  373,  378,  379,  375,  388,  378,  391,
      377,  392,  380,  396,  381,  382,  382,  392,  383,  394,

      381,  385,  385,  386,  386,  384,  387,  400,  388,  395,
      397,  399,  394,  388,  396,  391,  411,  392,  399,  396,
      404,  405,  412,  401,  400,  394,  246,  385,  417,  386,
      407,  395,  397,  400,  412,  395,  397,  399,  401,  407,
      409,  404,  405,  410,  414,  411,  404,  405,  412,  401,
      410,  413,  415,  409,  417,  418,  407,  416,  420,  419,
      413,  414,  421,  422,  422,  420,  409,  415,  423,  410,
      414,  424,  416,  425,  423,  426,  427,  413,  415,  419,
      430,  418,  431,  416,  420,  419,  433,  425,  421,  422,
      436,  437,  424,  438,  423,  442,  426,  424,  433,  425,

      427,  426,  427,  434,  439,  430,  430,  435,  431,  441,
      434,  436,  433,  444,  446,  435,  436,  437,  438,  438,
      443,  442,  441,  447,  448,  444,  450,  439,  443,  434,
      439,  452,  451,  435,  453,  441,  454,  446,  451,  444,
      446,  456,  457,  460,  447,  448,  443,  452,  456,  447,
      448,  232,  450,  191,  176,  173,  171,  452,  451,  137,
      453,  124,  454,  117,   87,   86,   84,  456,  457,  460,
      464,  464,  464,  464,  465,  465,  465,  465,  466,  466,
      466,  466,  468,  468,   82,  468,  469,  469,  471,  471,
      472,  472,   47,  472,   43,   39,   38,   33,   10,    9,

      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "configlexer.lex"
#line 2 "configlexer.lex"
/*
 * configlexer.lex - lexical analyzer for NSD config file
 *
 * Copyright (c) 2001-2011, NLnet Labs. All rights reserved
 *
 * See LICENSE for the license.
 *
 */

#include "config.h"

#include <ctype.h>
#include <errno.h>
#include <string.h>
#include <strings.h>

#include "options.h"
#include "configyyrename.h"
#include "configparser.h"
void c_error(const char *message);

#define YY_NO_UNPUT

#if 0
#define LEXOUT(s)  printf s /* used ONLY when debugging */
#else
#define LEXOUT(s)
#endif

struct inc_state {
	const char* filename;
	int line;
};
static struct inc_state parse_stack[MAXINCLUDES];
static YY_BUFFER_STATE include_stack[MAXINCLUDES];
static int config_include_stack_ptr = 0;

static void config_start_include(const char* filename)
{
	FILE *input;
	if(strlen(filename) == 0) {
		c_error_msg("empty include file name");
		return;
	}
	if(config_include_stack_ptr >= MAXINCLUDES) {
		c_error_msg("includes nested too deeply, skipped (>%d)", MAXINCLUDES);
		return;
	}
	input = fopen(filename, "r");
	if(!input) {
		c_error_msg("cannot open include file '%s': %s",
			filename, strerror(errno));
		return;
	}
	LEXOUT(("switch_to_include_file(%s) ", filename));
	parse_stack[config_include_stack_ptr].filename = cfg_parser->filename;
	parse_stack[config_include_stack_ptr].line = cfg_parser->line;
	include_stack[config_include_stack_ptr] = YY_CURRENT_BUFFER;
	cfg_parser->filename = region_strdup(cfg_parser->opt->region, filename);
	cfg_parser->line = 1;
	yy_switch_to_buffer(yy_create_buffer(input,YY_BUF_SIZE));
	++config_include_stack_ptr;
}

static void config_end_include(void)
{
	--config_include_stack_ptr;
	cfg_parser->filename = parse_stack[config_include_stack_ptr].filename;
	cfg_parser->line = parse_stack[config_include_stack_ptr].line;
	yy_delete_buffer(YY_CURRENT_BUFFER);
	yy_switch_to_buffer(include_stack[config_include_stack_ptr]);
}

#ifndef yy_set_bol /* compat definition, for flex 2.4.6 */
#define yy_set_bol(at_bol) \
        { \
	        if ( ! yy_current_buffer ) \
	                yy_current_buffer = yy_create_buffer(yyin,YY_BUF_SIZE ); \
	        yy_current_buffer->yy_ch_buf[0] = ((at_bol)?'\n':' '); \
        }
#endif


#line 1001 "<stdout>"

#define INITIAL 0
#define quotedstring 1
#define include 2
#define include_quoted 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 96 "configlexer.lex"

#line 1193 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 464 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1301 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 97 "configlexer.lex"
{ LEXOUT(("SP ")); /* ignore */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 98 "configlexer.lex"
{ LEXOUT(("comment(%s) ", yytext)); /* ignore */ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 99 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SERVER;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 100 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NAME;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 101 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP_ADDRESS;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 102 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DEBUG_MODE;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 103 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_HIDE_VERSION;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 104 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP4_ONLY;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 105 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP6_ONLY;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 106 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DATABASE;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 107 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IDENTITY;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 108 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NSID;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 109 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_LOGFILE;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 110 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SERVER_COUNT;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 111 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_TCP_COUNT;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 112 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_TCP_QUERY_COUNT;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 113 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_TCP_TIMEOUT;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 114 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IPV4_EDNS_SIZE;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 115 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IPV6_EDNS_SIZE;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 116 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PIDFILE;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 117 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PORT;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 118 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_STATISTICS;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 119 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONESTATSFILE;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 120 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CHROOT;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 121 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_USERNAME;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 122 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONESDIR;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 123 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DIFFFILE;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 124 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_XFRDFILE;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 125 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_XFRD_RELOAD_TIMEOUT;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 126 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERBOSITY;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 127 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONE;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 128 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONEFILE;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 129 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ALLOW_NOTIFY;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 130 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_REQUEST_XFR;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 131 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NOTIFY;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 132 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NOTIFY_RETRY;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 133 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PROVIDE_XFR;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 134 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_OUTGOING_INTERFACE;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 135 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ALLOW_AXFR_FALLBACK;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 136 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_KEY;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 137 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ALGORITHM;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 138 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SECRET;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 139 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_AXFR;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 140 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_UDP;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 141 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERIFY_IP_ADDRESS;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 142 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERIFY_PORT;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 143 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERIFIER_COUNT;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 144 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERIFIER;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 145 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERIFIER_FEED_ZONE;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 146 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERIFIER_TIMEOUT;}
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 147 "configlexer.lex"
{ LEXOUT(("NL\n")); cfg_parser->line++;}
	YY_BREAK
/* Quoted strings. Strip leading and ending quotes */
case 52:
YY_RULE_SETUP
#line 150 "configlexer.lex"
{ BEGIN(quotedstring); LEXOUT(("QS ")); }
	YY_BREAK
case YY_STATE_EOF(quotedstring):
#line 151 "configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 155 "configlexer.lex"
{ LEXOUT(("STR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 156 "configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 157 "configlexer.lex"
{
        LEXOUT(("QE "));
        BEGIN(INITIAL);
        yytext[yyleng - 1] = '\0';
	yylval.str = region_strdup(cfg_parser->opt->region, yytext);
        return STRING;
}
	YY_BREAK
/* include: directive */
case 56:
YY_RULE_SETUP
#line 166 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); BEGIN(include); }
	YY_BREAK
case YY_STATE_EOF(include):
#line 167 "configlexer.lex"
{
        yyerror("EOF inside include directive");
        BEGIN(INITIAL);
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 171 "configlexer.lex"
{ LEXOUT(("ISP ")); /* ignore */ }
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 172 "configlexer.lex"
{ LEXOUT(("NL\n")); cfg_parser->line++;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 173 "configlexer.lex"
{ LEXOUT(("IQS ")); BEGIN(include_quoted); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 174 "configlexer.lex"
{
	LEXOUT(("Iunquotedstr(%s) ", yytext));
	config_start_include(yytext);
	BEGIN(INITIAL);
}
	YY_BREAK
case YY_STATE_EOF(include_quoted):
#line 179 "configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 183 "configlexer.lex"
{ LEXOUT(("ISTR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 62:
/* rule 62 can match eol */
YY_RULE_SETUP
#line 184 "configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 185 "configlexer.lex"
{
	LEXOUT(("IQE "));
	yytext[yyleng - 1] = '\0';
	config_start_include(yytext);
	BEGIN(INITIAL);
}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 191 "configlexer.lex"
{
	yy_set_bol(1); /* Set beginning of line, so "^" rules match.  */
	if (config_include_stack_ptr == 0) {
		yyterminate();
	} else {
		fclose(yyin);
		config_end_include();
	}
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 201 "configlexer.lex"
{ LEXOUT(("unquotedstr(%s) ", yytext)); 
			yylval.str = region_strdup(cfg_parser->opt->region, yytext); return STRING; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 204 "configlexer.lex"
ECHO;
	YY_BREAK
#line 1662 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 464 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 464 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 463);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 204 "configlexer.lex"



